@@ -13,7 +13,7 @@ sub generate {
   my $cfg      = shift;
   my $entries = shift;
 
-  my $now = DateTime->now;
+  my $now = DateTime->now(time_zone => 'local');
 
   for my $i (0 .. @$entries) {
     my $entry = $entries->[$i];
